from setuptools import setup

setup(name='distributions_proba',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['distributions_proba'],
      author = 'Gizella Nádor',
      author_email = 'gizella.nador@gmail.com',
    zip_safe=False)
